==> foundation-2.6.1.tgz: package/Blind/Blind.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Blind = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("circle", {
    cx: 41.53,
    cy: 19.773,
    r: 7.152
  }), /*#__PURE__*/React.createElement("path", {
    d: "M83.162 84.562l.01-.006-20.92-36.234a2.978 2.978 0 00.577-1.756 3 3 0 00-1.887-2.783L54.907 40.3l-9.159-9.159a7.135 7.135 0 00-5.552-2.647 7.125 7.125 0 00-5.152 2.199L24.412 41.324l.012.012a.719.719 0 00-.285.564c0 .056.02.104.032.156h-.029v11.975c0 .009-.003.017-.003.025a3.003 3.003 0 006.005 0l-.002-.024v-10.01l3.649-3.649V59.18h.001l-6.954 12.044-8.891 8.891.033.033a4.16 4.16 0 00-1.339 3.052 4.18 4.18 0 004.181 4.18c1.317 0 2.476-.621 3.243-1.571l9.596-9.596-.037-.037 8.096-14.024 7.104 7.104 9.232 15.99.036-.021c.715 1.278 2.066 2.153 3.635 2.153a4.18 4.18 0 004.181-4.18c0-.915-.302-1.754-.8-2.443l-9.627-16.674-.012.007-8.679-8.678V40.609l4.451 4.451-.001.002.007.004.025.025.007-.007 6.847 3.954c.054.037.113.064.169.098l.028.016v-.001c.443.258.952.417 1.502.417.189 0 .372-.022.552-.056l20.816 36.054c.013.032.034.057.05.087l.007.012h.001a1.117 1.117 0 002.107-.511 1.066 1.066 0 00-.196-.592z"
  })));
});
Blind.displayName = 'Blind';
export const BlindDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/Blind/Blind.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Blind = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("circle", {
    cx: 41.53,
    cy: 19.773,
    r: 7.152
  }), /*#__PURE__*/React.createElement("path", {
    d: "M83.162 84.562l.01-.006-20.92-36.234a2.978 2.978 0 00.577-1.756 3 3 0 00-1.887-2.783L54.907 40.3l-9.159-9.159a7.135 7.135 0 00-5.552-2.647 7.125 7.125 0 00-5.152 2.199L24.412 41.324l.012.012a.719.719 0 00-.285.564c0 .056.02.104.032.156h-.029v11.975c0 .009-.003.017-.003.025a3.003 3.003 0 006.005 0l-.002-.024v-10.01l3.649-3.649V59.18h.001l-6.954 12.044-8.891 8.891.033.033a4.16 4.16 0 00-1.339 3.052 4.18 4.18 0 004.181 4.18c1.317 0 2.476-.621 3.243-1.571l9.596-9.596-.037-.037 8.096-14.024 7.104 7.104 9.232 15.99.036-.021c.715 1.278 2.066 2.153 3.635 2.153a4.18 4.18 0 004.181-4.18c0-.915-.302-1.754-.8-2.443l-9.627-16.674-.012.007-8.679-8.678V40.609l4.451 4.451-.001.002.007.004.025.025.007-.007 6.847 3.954c.054.037.113.064.169.098l.028.016v-.001c.443.258.952.417 1.502.417.189 0 .372-.022.552-.056l20.816 36.054c.013.032.034.057.05.087l.007.012h.001a1.117 1.117 0 002.107-.511 1.066 1.066 0 00-.196-.592z"
  })));
});
Blind.displayName = 'Blind';
export var BlindDimensions = {
  height: 100,
  width: 100
};
